
Citing
======

If you find curver useful in your research, please consider citing it. A suggested
reference is::

    Mark Bell. curver (Computer Software).
    pypi.python.org/pypi/curver, 2017. Version <<version number>>

the BibTeX entry::

    @Misc{curver,
        author = {Bell, Mark},
        title = {curver (Computer Software)},
        howpublished = {\url{pypi.python.org/pypi/curver}},
        year = {2017},
        note = {Version <<version number>>}
    }

or the BibItem::

    \bibitem{curver} Mark Bell: \emph{curver (Computer Software)},
        \url{pypi.python.org/pypi/curver}, (2017),
        Version <<version number>>.
